@@ -1,5 +1,5 @@
 package Tangerine;
-$Tangerine::VERSION = '0.12';
+$Tangerine::VERSION = '0.13';
 # ABSTRACT: Analyse perl files and report module-related information
 use 5.010;
 use strict;
@@ -22,7 +22,10 @@ has uses => {};
 my %hooks;
 $hooks{prov} = [ qw(package) ];
 $hooks{req} = [ qw(require) ];
-$hooks{use} = [ qw(use list prefixedlist anymoose if mooselike testrequires tests xxx) ];
+$hooks{use} = [
+    qw(use list prefixedlist anymoose if inline moduleruntime mooselike
+       testrequires tests xxx)
+    ];
 
 sub run {
     my $self = shift;
