@@ -1,5 +1,5 @@
 package Tangerine::hook::prefixedlist;
-$Tangerine::hook::prefixedlist::VERSION = '0.12';
+$Tangerine::hook::prefixedlist::VERSION = '0.13';
 use 5.010;
 use strict;
 use warnings;
@@ -14,7 +14,7 @@ extends 'Tangerine::Hook';
 sub run {
     my ($self, $s) = @_;
     if ((any { $s->[0] eq $_ } qw(use no)) && scalar(@$s) > 2 &&
-        (any { $s->[1] eq $_ } qw(Inline Mo POE))) {
+        (any { $s->[1] eq $_ } qw(Mo POE))) {
         my ($version) = $s->[2] =~ /^(\d.*)$/o;
         $version //= '';
         my $voffset = $version ? 3 : 2;
@@ -25,8 +25,6 @@ sub run {
             @args = @args[($voffset) .. $#args];
             @args = stripquotelike(@args);
         }
-        @args = $args[0] ? ($args[0]) : ()
-            if $s->[1] eq 'Inline';
         return Tangerine::HookData->new(
             modules => {
                 map {
@@ -56,7 +54,7 @@ This hook catches C<use> statements with modules loading more modules
 listed as their arguments.  The difference from L<Tangerine::hook::list>
 is these modules use the same namespace as the module loading them.
 
-Currently this hook knows about L<Inline>, L<Mo> and L<POE>.
+Currently this hook knows about L<Mo> and L<POE>.
 
 =head1 AUTHOR
 
